LocationRadius

Struct LocationRadius 

pub struct LocationRadius { /* private fields */ }
A positive radius around a location, stored in meters.

Implementations

Source

impl LocationRadius

pub fn from_meters(meters: f64) -> Result<Self, GeoValueError>

Creates a radius from meters.

Errors

Returns GeoValueError::InvalidRadius when the value is not positive and finite.

pub fn from_kilometers(kilometers: f64) -> Result<Self, GeoValueError>

Creates a radius from kilometers.

Errors

Returns GeoValueError::InvalidRadius when the value is not positive and finite.

pub const fn meters(self) -> f64

Returns the radius in meters.